==> jei-1.21.5-fabric-21.3.0.17-sources.jar: mezz/jei/gui/elements/GuiIconButton.java <==
package mezz.jei.gui.elements;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.common.input.IInternalKeyMappings;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.gui.input.IUserInputHandler;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_768;
import net.minecraft.class_8666;
import net.minecraft.class_9848;
import java.util.Optional;

/**
 * A gui button that has an {@link IDrawable} instead of a string label.
 */
public class GuiIconButton extends class_4185 {
	private static final class_8666 SPRITES = new class_8666(class_2960.method_60656("widget/button"), class_2960.method_60656("widget/button_disabled"), class_2960.method_60656("widget/button_highlighted"));

	private IDrawable icon;
	private boolean pressed = false;
	private boolean forcePressed = false;

	public GuiIconButton(int x, int y, int width, int height, IDrawable icon, class_4241 pressable) {
		super(x, y, width, height, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public GuiIconButton(IDrawable icon, class_4241 pressable) {
		super(0, 0, 0, 0, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public void updateBounds(class_768 area) {
		method_46421(area.method_3321());
		method_46419(area.method_3322());
		this.field_22758 = area.method_3319();
		this.field_22759 = area.method_3320();
	}

	public void updateBounds(ImmutableRect2i area) {
		method_46421(area.getX());
		method_46419(area.getY());
		this.field_22758 = area.getWidth();
		this.field_22759 = area.getHeight();
	}

	@Override
	public void method_53533(int value) {
		this.field_22759 = value;
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTicks) {
		guiGraphics.method_52707(class_1921::method_62277, SPRITES.method_52729(this.field_22763, this.method_25367()), this.method_46426(), this.method_46427(), this.method_25368(), this.method_25364(), class_9848.method_61317(this.field_22765));

		double xOffset = method_46426() + (field_22758 - icon.getWidth()) / 2.0;
		double yOffset = method_46427() + (field_22759 - icon.getHeight()) / 2.0;
		if (this.pressed || this.forcePressed) {
			xOffset += 0.5;
			yOffset += 0.5;
		}
		var poseStack = guiGraphics.method_51448();
		poseStack.method_22903();
		{
			poseStack.method_22904(xOffset, yOffset, 0);
			icon.draw(guiGraphics);
		}
		poseStack.method_22909();
	}

	public IUserInputHandler createInputHandler() {
		return new UserInputHandler(this);
	}

	public void setForcePressed(boolean forcePressed) {
		this.forcePressed = forcePressed;
	}

	public ImmutableRect2i getArea() {
		return new ImmutableRect2i(method_46426(), method_46427(), field_22758, field_22759);
	}

	public void setIcon(IDrawable icon) {
		this.icon = icon;
	}

	private class UserInputHandler implements IUserInputHandler {
		private final GuiIconButton button;

		public UserInputHandler(GuiIconButton button) {
			this.button = button;
		}

		@Override
		public Optional<IUserInputHandler> handleUserInput(class_437 screen, UserInput input, IInternalKeyMappings keyBindings) {
			this.button.pressed = false;

			double mouseX = input.getMouseX();
			double mouseY = input.getMouseY();
			if (!this.button.field_22763 || !this.button.field_22764 || !method_25405(mouseX, mouseY)) {
				return Optional.empty();
			}
			if (!this.button.method_25351(input.getKey().method_1444())) {
				return Optional.empty();
			}
			if (!input.isSimulate()) {
				this.button.method_25354(class_310.method_1551().method_1483());
				this.button.method_25348(mouseX, mouseY);
			} else {
				this.button.pressed = true;
			}
			return Optional.of(this);
		}

		@Override
		public void unfocus() {
			this.button.pressed = false;
		}
	}
}

==> jei-1.21.8-fabric-24.1.0.5-sources.jar: mezz/jei/gui/elements/GuiIconButton.java <==
package mezz.jei.gui.elements;

import mezz.jei.api.gui.drawable.IDrawable;
import mezz.jei.api.gui.handlers.IGuiProperties;
import mezz.jei.common.input.IInternalKeyMappings;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.gui.input.IUserInputHandler;
import mezz.jei.gui.input.UserInput;
import net.minecraft.class_10799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_768;
import net.minecraft.class_8666;
import net.minecraft.class_9848;
import java.util.Optional;

/**
 * A gui button that has an {@link IDrawable} instead of a string label.
 */
public class GuiIconButton extends class_4185 {
	private static final class_8666 SPRITES = new class_8666(class_2960.method_60656("widget/button"), class_2960.method_60656("widget/button_disabled"), class_2960.method_60656("widget/button_highlighted"));

	private IDrawable icon;
	private boolean pressed = false;
	private boolean forcePressed = false;

	public GuiIconButton(int x, int y, int width, int height, IDrawable icon, class_4241 pressable) {
		super(x, y, width, height, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public GuiIconButton(IDrawable icon, class_4241 pressable) {
		super(0, 0, 0, 0, class_5244.field_39003, pressable, class_4185.field_40754);
		this.icon = icon;
	}

	public void updateBounds(class_768 area) {
		method_46421(area.method_3321());
		method_46419(area.method_3322());
		this.field_22758 = area.method_3319();
		this.field_22759 = area.method_3320();
	}

	public void updateBounds(ImmutableRect2i area) {
		method_46421(area.getX());
		method_46419(area.getY());
		this.field_22758 = area.getWidth();
		this.field_22759 = area.getHeight();
	}

	@Override
	public void method_53533(int value) {
		this.field_22759 = value;
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTicks) {
		class_2960 spriteLocation = SPRITES.method_52729(this.field_22763, this.method_25367());
		guiGraphics.method_52707(class_10799.field_56883, spriteLocation, this.method_46426(), this.method_46427(), this.method_25368(), this.method_25364(), class_9848.method_61317(this.field_22765));

		float xOffset = method_46426() + (field_22758 - icon.getWidth()) / 2.0f;
		float yOffset = method_46427() + (field_22759 - icon.getHeight()) / 2.0f;
		if (this.pressed || this.forcePressed) {
			xOffset += 0.5f;
			yOffset += 0.5f;
		}
		var poseStack = guiGraphics.method_51448();
		poseStack.pushMatrix();
		{
			poseStack.translate(xOffset, yOffset);
			icon.draw(guiGraphics);
		}
		poseStack.popMatrix();
	}

	public IUserInputHandler createInputHandler() {
		return new UserInputHandler(this);
	}

	public void setForcePressed(boolean forcePressed) {
		this.forcePressed = forcePressed;
	}

	public ImmutableRect2i getArea() {
		return new ImmutableRect2i(method_46426(), method_46427(), field_22758, field_22759);
	}

	public void setIcon(IDrawable icon) {
		this.icon = icon;
	}

	private class UserInputHandler implements IUserInputHandler {
		private final GuiIconButton button;

		public UserInputHandler(GuiIconButton button) {
			this.button = button;
		}

		@Override
		public Optional<IUserInputHandler> handleUserInput(class_437 screen, IGuiProperties guiProperties, UserInput input, IInternalKeyMappings keyBindings) {
			this.button.pressed = false;

			double mouseX = input.getMouseX();
			double mouseY = input.getMouseY();
			if (!this.button.field_22763 || !this.button.field_22764 || !method_25405(mouseX, mouseY)) {
				return Optional.empty();
			}
			if (!this.button.method_25351(input.getKey().method_1444())) {
				return Optional.empty();
			}
			if (!input.isSimulate()) {
				this.button.method_25354(class_310.method_1551().method_1483());
				this.button.method_25348(mouseX, mouseY);
			} else {
				this.button.pressed = true;
			}
			return Optional.of(this);
		}

		@Override
		public void unfocus() {
			this.button.pressed = false;
		}
	}
}
